# Dies ist ein einfaches Programm für die Projektarbeit.
# Autor: Jan-Erik Engeln

antwort =  input("Wer leitet das Projektstudium in E-Business? Antwort hier: ")

if antwort in ["Martin Hepp", "Prof. Hepp", "Dr. Hepp", "Prof. Dr. Hepp"]:
	print ("Richtig!")

else: 
	print ("Schau lieber nochmal nach!")

input ()




