from distutils.core import setup

setup (
	name='Projektarbeit',
	version='0.1',
	author='eryk94',
	packages=['projektarbeit'],
	scripts=['bin/project.py'],
	license='Creative Commons Attribution-Noncommercial-Share Alike license',
	description='Example for How-to create a package'
)
